==> u61-0.3.0.tar.gz: u61-0.3.0/src/playerconfig.h <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   playerconfig.h
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: designed to be a member of the config class, and store
 *              information about a player
 */


#ifndef INC_U61_PLAYERCONFIG
#define INC_U61_PLAYERCONFIG

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include <ClanLib/core.h>

#include "const.h"

/*---------------------------------------------------------------------------
 classes
 ---------------------------------------------------------------------------*/

class U61_PlayerConfig
{
 public:
  U61_PlayerConfig();
  ~U61_PlayerConfig();

  bool activable;

  char name[U61_STRING_SIZE];

  bool prevision;

  int key_start_stop;
  int key_move_left;
  int key_move_right;
  int key_rotate_left;
  int key_rotate_right;
  int key_move_down;
  int key_drop;
  int key_next_victim;
  int key_prev_victim;
  int key_use_antedote;
  
  int first_repeat_move;
  int standard_repeat_move;
  int first_repeat_rotate;
  int standard_repeat_rotate;
  int first_repeat_other;
  int standard_repeat_other;
    
 protected:

};

#endif

==> u61-0.3.2.tar.gz: u61-0.3.2/src/playerconfig.h <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   playerconfig.h
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: designed to be a member of the config class, and store
 *              information about a player
 */


#ifndef INC_U61_PLAYERCONFIG
#define INC_U61_PLAYERCONFIG

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include <ClanLib/core.h>

#include "const.h"

/*---------------------------------------------------------------------------
 classes
 ---------------------------------------------------------------------------*/

class U61_PlayerConfig
{
 public:
  U61_PlayerConfig();
  ~U61_PlayerConfig();

  bool activable;

  char name[U61_STRING_SIZE];

  bool anticipation;

  int key_start_stop;
  int key_move_left;
  int key_move_right;
  int key_rotate_left;
  int key_rotate_right;
  int key_move_down;
  int key_drop;
  int key_next_victim;
  int key_prev_victim;
  int key_use_antidote;
  
  int first_repeat_move;
  int standard_repeat_move;
  int first_repeat_rotate;
  int standard_repeat_rotate;
  int first_repeat_other;
  int standard_repeat_other;
    
 protected:

};

#endif
